@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0405';
+our $VERSION = '0.0406';
 
 use strictures 2;
 use AI::Prolog ();
@@ -271,7 +271,7 @@ Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0405
+version 0.0406
 
 =head1 SYNOPSIS
 
@@ -302,13 +302,21 @@ version 0.0405
   #  ... ]
   # Inspecting all the results, we see that the answers are D Dorian, D Ionian, and D Mixolydian.
 
+  # What chords do C major and A minor have in common?
+  $m = Music::ModalFunction->new(
+    mode_note    => 'c',
+    mode         => 'ionian',
+    key_note     => 'a',
+    key          => 'aeolian',
+  );
+  $results = $m->pivot_chord_keys; # 7 common chords
+
   # What chords do C major and F♯ (G♭) major have in common?
   $m = Music::ModalFunction->new(
     mode_note    => 'c',
     mode         => 'ionian',
     key_note     => 'gb',
     key          => 'ionian',
-    hash_results => 1,
   );
   $results = $m->pivot_chord_keys; # There are no chords in common!
 
